#
# MOTools_AutoWrite.py
#
# www.MikeOakley.com
#
#
import os
import nuke

def createautowrite():
    # checking if files been saved
    if nuke.root().name() == 'root':
        nuke.message('Please save the nuke script first')
        return
     
    # check if file has versioning
    autowrite_correctfilename = os.path.basename(nuke.root().name()).split('_v')[1].split('.nk')[0]
    if not autowrite_correctfilename:
        nuke.message('File name ending should be in a _v000 format')
        return
        
    # ask for comp folder and if non is selected stop script
    autowrite_usercomppath = nuke.getFilename("Select Nuke Render Folder")
    if not autowrite_usercomppath:
        nuke.message('Cancelled : Directory not selected')
        return
       
    #creates a unique write node name
    autowrite = nuke.createNode('Write', inpanel=True)
    count = 1
    while nuke.exists('Autowrite_' + str(count)):
        count += 1
    autowrite.knob('name').setValue('Autowrite_' + str(count))
    
    # setup defaultss
    autowrite.knob('channels').setValue('rgb')
    autowrite.knob('colorspace').setValue('linear')    
    autowrite.knob('file_type').setValue('targa')

    # create settings tabs
    t = nuke.Tab_Knob("Settings")
    autowrite.addKnob(t)
    
    autowrite.addKnob(nuke.File_Knob('autowrite_comppath', 'Render Folder'))
    autowrite['autowrite_comppath'].setValue(autowrite_usercomppath)
    autowrite_comppath = autowrite_usercomppath
    
    autowrite.addKnob(nuke.Text_Knob("divName","",""))        

    autowrite.addKnob(nuke.Text_Knob("","Extra Info : Finals, leftview, user, filetype, jpegs",""))
    autowrite.addKnob(nuke.EvalString_Knob('autowrite_extrainfo','Extra info',''))
    autowrite['autowrite_extrainfo'].setValue('')


def updateautowrite():
    try:
        thisautowrite = nuke.thisNode()

        # get varibles from user
        autowrite_get_name =thisautowrite.knob('name')
        
        autowrite_get_comppath = thisautowrite['autowrite_comppath'].value()
        
        autowrite_get_scriptname = os.path.basename(nuke.root().name()).split('_v')[0]
        
        autowrite_get_version = os.path.basename(nuke.root().name()).split('_v')[1].split('.nk')[0]
        if thisautowrite['autowrite_extrainfo'].value() == 1 :  autowrite_get_version = ""
        
        autowrite_get_extrainfo = thisautowrite['autowrite_extrainfo'].value()        
        if autowrite_get_extrainfo != '' : autowrite_get_extrainfo = '_' + autowrite_get_extrainfo
        
        autowrite_get_filetype = thisautowrite['file_type'].value()
        autowrite_seq = '####.'
        
        # fix image type names
        if autowrite_get_filetype == 'mov': autowrite_seq = ''
        elif autowrite_get_filetype == 'jpeg': autowrite_get_filetype = 'jpg'
        elif autowrite_get_filetype == 'tiff': autowrite_get_filetype = 'tif'
        elif autowrite_get_filetype == 'targa': autowrite_get_filetype = 'tga' 
      
        autowrite_output = '%s%s/v%s/%s%s_v%s.%s%s' % (autowrite_get_comppath, autowrite_get_scriptname, autowrite_get_version, autowrite_get_scriptname,autowrite_get_extrainfo,autowrite_get_version,autowrite_seq,autowrite_get_filetype )     
        thisautowrite['file'].setValue(autowrite_output)
        
        #feedback = """
        #Shot : [value autowrite_get_scriptname]
        #Ver  : [value autowrite_get_version]
        #"""
        #thisautowrite.knob('label').setValue(feedback)
        
        return
    except:
        return